.. image:: https://travis-ci.com/jugmac00/Products.ZopeTree.svg?branch=master
  :target: https://travis-ci.com/jugmac00/Products.ZopeTree

.. image:: https://coveralls.io/repos/github/jugmac00/Products.ZopeTree/badge.svg?branch=master
  :target: https://coveralls.io/github/jugmac00/Products.ZopeTree?branch=master

.. image:: https://img.shields.io/pypi/v/Products.ZopeTree.svg
  :target: https://pypi.org/project/Products.ZopeTree/

.. image:: https://img.shields.io/pypi/pyversions/Products.ZopeTree.svg
  :target: https://pypi.org/project/Products.ZopeTree/

.. image:: https://requires.io/github/jugmac00/Products.ZopeTree/requirements.svg?branch=master
  :target: https://requires.io/github/jugmac00/Products.ZopeTree/requirements/?branch=master

.. image:: https://img.shields.io/pypi/l/Products.ZopeTree
  :alt: PyPI - License


Products.ZopeTree
=================

ZopeTree is a light-weight tree implementation, mainly for use with ZPT.

Created by Philipp "philiKON" von Weitershausen.

Scope
-----

This package back from 2003 has been asleep for more than a decade.

It was about time to get up and get ready for Zope 4 and Python 3.

The package is considered feature-complete.
